@@ -373,6 +373,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.assets
@@ -433,7 +435,7 @@ class BucketDeployment(
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
-        metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
+        metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
         prune: typing.Optional[builtins.bool] = None,
         retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
@@ -443,7 +445,7 @@ class BucketDeployment(
         storage_class: typing.Optional["StorageClass"] = None,
         use_efs: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -479,6 +481,10 @@ class BucketDeployment(
         :param vpc_subnets: Where in the VPC to place the deployment lambda handler. Only used if 'vpc' is supplied. Default: - the Vpc default strategy if not specified
         :param website_redirect_location: System-defined x-amz-website-redirect-location metadata to be set on all objects in the deployment. Default: - No website redirection.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(BucketDeployment.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BucketDeploymentProps(
             destination_bucket=destination_bucket,
             sources=sources,
@@ -583,7 +589,7 @@ class BucketDeploymentProps:
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
-        metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
+        metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
         prune: typing.Optional[builtins.bool] = None,
         retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
@@ -593,7 +599,7 @@ class BucketDeploymentProps:
         storage_class: typing.Optional["StorageClass"] = None,
         use_efs: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        vpc_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Properties for ``BucketDeployment``.
@@ -649,6 +655,37 @@ class BucketDeploymentProps:
             metadata = UserDefinedObjectMetadata(**metadata)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
+        if __debug__:
+            type_hints = typing.get_type_hints(BucketDeploymentProps.__init__)
+            check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
+            check_type(argname="argument sources", value=sources, expected_type=type_hints["sources"])
+            check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
+            check_type(argname="argument cache_control", value=cache_control, expected_type=type_hints["cache_control"])
+            check_type(argname="argument content_disposition", value=content_disposition, expected_type=type_hints["content_disposition"])
+            check_type(argname="argument content_encoding", value=content_encoding, expected_type=type_hints["content_encoding"])
+            check_type(argname="argument content_language", value=content_language, expected_type=type_hints["content_language"])
+            check_type(argname="argument content_type", value=content_type, expected_type=type_hints["content_type"])
+            check_type(argname="argument destination_key_prefix", value=destination_key_prefix, expected_type=type_hints["destination_key_prefix"])
+            check_type(argname="argument distribution", value=distribution, expected_type=type_hints["distribution"])
+            check_type(argname="argument distribution_paths", value=distribution_paths, expected_type=type_hints["distribution_paths"])
+            check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument expires", value=expires, expected_type=type_hints["expires"])
+            check_type(argname="argument include", value=include, expected_type=type_hints["include"])
+            check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
+            check_type(argname="argument memory_limit", value=memory_limit, expected_type=type_hints["memory_limit"])
+            check_type(argname="argument metadata", value=metadata, expected_type=type_hints["metadata"])
+            check_type(argname="argument prune", value=prune, expected_type=type_hints["prune"])
+            check_type(argname="argument retain_on_delete", value=retain_on_delete, expected_type=type_hints["retain_on_delete"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument server_side_encryption", value=server_side_encryption, expected_type=type_hints["server_side_encryption"])
+            check_type(argname="argument server_side_encryption_aws_kms_key_id", value=server_side_encryption_aws_kms_key_id, expected_type=type_hints["server_side_encryption_aws_kms_key_id"])
+            check_type(argname="argument server_side_encryption_customer_algorithm", value=server_side_encryption_customer_algorithm, expected_type=type_hints["server_side_encryption_customer_algorithm"])
+            check_type(argname="argument storage_class", value=storage_class, expected_type=type_hints["storage_class"])
+            check_type(argname="argument use_efs", value=use_efs, expected_type=type_hints["use_efs"])
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
+            check_type(argname="argument website_redirect_location", value=website_redirect_location, expected_type=type_hints["website_redirect_location"])
         self._values: typing.Dict[str, typing.Any] = {
             "destination_bucket": destination_bucket,
             "sources": sources,
@@ -1077,6 +1114,9 @@ class CacheControl(
 
         :param s: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CacheControl.from_string)
+            check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "fromString", [s]))
 
     @jsii.member(jsii_name="maxAge") # type: ignore[misc]
@@ -1086,6 +1126,9 @@ class CacheControl(
 
         :param t: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CacheControl.max_age)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "maxAge", [t]))
 
     @jsii.member(jsii_name="mustRevalidate") # type: ignore[misc]
@@ -1131,6 +1174,9 @@ class CacheControl(
 
         :param t: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CacheControl.s_max_age)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "sMaxAge", [t]))
 
     @builtins.property # type: ignore[misc]
@@ -1166,6 +1212,9 @@ class DeploymentSourceContext:
                 handler_role=role
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DeploymentSourceContext.__init__)
+            check_type(argname="argument handler_role", value=handler_role, expected_type=type_hints["handler_role"])
         self._values: typing.Dict[str, typing.Any] = {
             "handler_role": handler_role,
         }
@@ -1219,6 +1268,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Expires.after)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "after", [t]))
 
     @jsii.member(jsii_name="atDate") # type: ignore[misc]
@@ -1230,6 +1282,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Expires.at_date)
+            check_type(argname="argument d", value=d, expected_type=type_hints["d"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atDate", [d]))
 
     @jsii.member(jsii_name="atTimestamp") # type: ignore[misc]
@@ -1241,6 +1296,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Expires.at_timestamp)
+            check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("Expires", jsii.sinvoke(cls, "atTimestamp", [t]))
 
     @jsii.member(jsii_name="fromString") # type: ignore[misc]
@@ -1252,6 +1310,9 @@ class Expires(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Exp
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Expires.from_string)
+            check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("Expires", jsii.sinvoke(cls, "fromString", [s]))
 
     @builtins.property # type: ignore[misc]
@@ -1300,6 +1361,9 @@ class _ISourceProxy:
         :param scope: The construct tree context.
         :param handler_role: The role for the handler.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ISource.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         context = DeploymentSourceContext(handler_role=handler_role)
 
         return typing.cast("SourceConfig", jsii.invoke(self, "bind", [scope, context]))
@@ -1390,7 +1454,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         follow_symlinks: typing.Optional[aws_cdk.core.SymlinkFollowMode] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
-        bundling: typing.Optional[aws_cdk.core.BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[aws_cdk.core.BundlingOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> ISource:
         '''Uses a local asset as the deployment source.
 
@@ -1408,6 +1472,9 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
         :param bundling: Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Source.asset)
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         options = aws_cdk.aws_s3_assets.AssetOptions(
             readers=readers,
             source_hash=source_hash,
@@ -1436,6 +1503,10 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param bucket: The S3 Bucket.
         :param zip_object_key: The S3 object key of the zip file with contents.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Source.bucket)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
         return typing.cast(ISource, jsii.sinvoke(cls, "bucket", [bucket, zip_object_key]))
 
     @jsii.member(jsii_name="data") # type: ignore[misc]
@@ -1452,6 +1523,10 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param object_key: The destination S3 object key (relative to the root of the S3 deployment).
         :param data: The data to be stored in the object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Source.data)
+            check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         return typing.cast(ISource, jsii.sinvoke(cls, "data", [object_key, data]))
 
     @jsii.member(jsii_name="jsonData") # type: ignore[misc]
@@ -1466,6 +1541,10 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-s3-deployment.Sour
         :param object_key: The destination S3 object key (relative to the root of the S3 deployment).
         :param obj: A JSON object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Source.json_data)
+            check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
+            check_type(argname="argument obj", value=obj, expected_type=type_hints["obj"])
         return typing.cast(ISource, jsii.sinvoke(cls, "jsonData", [object_key, obj]))
 
 
@@ -1514,6 +1593,11 @@ class SourceConfig:
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SourceConfig.__init__)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
+            check_type(argname="argument markers", value=markers, expected_type=type_hints["markers"])
         self._values: typing.Dict[str, typing.Any] = {
             "bucket": bucket,
             "zip_object_key": zip_object_key,
